<template>
    <div
        class="full-page"
        element-loading-text="数据加载中..."
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)"
        v-loading.fullscreen.lock="markLoading"
    >
        <div class="search-container">
            <el-form :inline="true" :model="parameter">
                <el-row :gutter="10">
                    <el-col :span="6">
                        <el-form-item style="width: 100%" label="组织名称">
                            <el-input
                                clearable
                                v-model="orgName"
                                placeholder="请输入组织名称"
                            ></el-input>
                        </el-form-item>
                    </el-col>
                    <!-- <el-col :span="6">
                        <el-form-item label="对象类型">
                            <el-select
                                stylEventRegistration="width: 100%"
                                v-model="querys[1].value"
                                clearable
                                placeholder="请选择对象类型"
                            >
                                <el-option
                                    v-for="item in dxlxList"
                                    :key="item.value"
                                    :label="item.name"
                                    :value="item.value"
                                >
                                </el-option>
                            </el-select>
                        </el-form-item>
                    </el-col> -->
                    <el-col :span="2">
                        <el-button
                            type="primary"
                            @click="getData(1)"
                            icon="el-icon-search"
                            >查询</el-button
                        >
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" :class="['main-table-container', 'flex']">
            <el-col
                :span="24"
                class="table-container"
                ref="contentPanel"
                style="padding: 20px"
            >
                <div style="margin-bottom: 10px" ref="btnPanel"></div>
                <div class="table-wrapper">
                    <el-table
                        height="100%"
                        row-key="id"
                        align="center"
                        :data="tableData"
                        :cell-style="{'text-align': 'center'}"
                        style="min-width: 100%; overflow: auto"
                        :header-cell-style="{'text-align': 'center'}"
                        v-loading="loading"
                        ref="table"
                    >
                        <el-table-column
                            type="index"
                            width="60"
                            label="序号"
                        ></el-table-column>
                        <el-table-column
                            prop="orgName"
                            label="组织名称"
                        ></el-table-column>
                        <el-table-column
                            prop="addvcdName"
                            label="行政区划"
                        ></el-table-column>
                        <el-table-column
                            prop="advanceProcessing"
                            label="提前处理（次）"
                        ></el-table-column>
                        <el-table-column
                            prop="overTimeProcessing"
                            label="超期处理（次）"
                        ></el-table-column>
                        <el-table-column
                            prop="plannedProcessing"
                            label="如期处理（次）"
                        ></el-table-column>
                    </el-table>
                </div>
                <pagination
                    ref="paginationPanel"
                    style="margin-top: 10px"
                    :pageResult="pageResult"
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                />
            </el-col>
        </el-row>
    </div>
</template>
<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import comprehensiveAssessment from '@/api/Comprehensive/comprehensiveAssessment.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import utils from '@/utils.js'
export default {
    name: 'comprehensiveAssessment',
    components: {
        pagination,
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            tableMaxHeight: 400,
            tableData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            querys: [
                // {
                //     group: 'main',
                //     operation: 'LIKE',
                //     parentGroup: '',
                //     property: 'orgName',
                //     relation: 'AND',
                //     value: '',
                // },
                // {
                //     group: 'main',
                //     operation: 'EQUAL',
                //     parentGroup: '',
                //     property: 'type',
                //     relation: 'AND',
                //     value: '',
                // },
            ],
            reqData: {
                querys: [],
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                params: {
                    orgName: '',
                },
            },
            tableLoading: false,
            parameter: {
                size: 20,
                page: 1,
            },
            dxlxList: [], // 对象类型
            orgName: '',
        }
    },
    created() {
        this.dxlxList = dictUtils.getDictItemsFromCache('dxlx')
        this.getData()
    },
    methods: {
        //获取数据
        getData(page) {
            if (page) {
                this.reqData.pageBean.page = page
            }
            this.reqData.querys = []
            // if (this.querys[0].value) {
            //     this.reqData.querys.push(this.querys[0])
            // }
            // if (this.querys[1].value) {
            //     this.reqData.querys.push(this.querys[1])
            // }
            this.reqData.params.orgName = this.orgName
            this.tableLoading = true
            comprehensiveAssessment.dataQuery(this.reqData, (res) => {
                this.pageResult.total = res.total
                this.tableLoading = false
                this.tableData = res.rows
            })
        },
        handleSizeChange(val) {
            this.reqData.pageBean.pageSize = val
            this.getData()
        },
        handleCurrentChange(val) {
            this.reqData.pageBean.page = val
            this.getData()
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
    },
}
</script>
<style lang='scss' scoped>
@import '~@/assets/css/element-variables.scss';
@import '~@/assets/css/common.scss';

.table-wrapper {
    height: calc(100% - 50px);
}
</style>
